/*
Calculator-komponentin luokkaosa 

Komponentin luokkaosassa on TypeScriptillä koodattu sovelluslogiikka
Luokasta välitetään dataa käyttölittymään eli templaattiin ja toisinpäin.
Luokkaosaa kutsutaan myös varsinaiseksi komponentiksi, sillä se sisältää
kaikki komponentin osat määriteltynä dekoraattorissa.
*/

import { Component, OnInit } from '@angular/core';
import { StorageService } from '../storage.service';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

// @Component -dekoraattorimetodin argumenttina
// olevassa oliossa määritellään komponentin osat
@Component({
  selector: 'app-calculator', // komponentin html-tagi
  standalone: true,
  imports: [FormsModule, CommonModule],
  templateUrl: './calculator.component.html', // templaatti
  styleUrl: './calculator.component.css' // tyylitiedosto
})
/*
Luokassa on ominaisuuksia eli propertyjä ja
toiminnallisuuksia eli metodeja (luokan funktiota)
*/
export class CalculatorComponent implements OnInit {
  //propertyt
  val1: number; // TS:ssä tietotyyppi merkitään kaksoispisteen perään
  val2: number; // val1 ja val2 -arvot saadaan templaatin lomakkeelta
  result: number; // result lasketaan tässä luokassa
  calcs: string[];
  

  // konstruktori antaa luokasta syntyvän olion muuttujille alkuarvot
  constructor(private sservice: StorageService) {
    this.val1 = 0;
    this.val2 = 0;
    this.result = 0;
    this.calcs = []; 
  }

  // ngOnInit() suoritetaan automaattisesti aina kun sovellus käynnistyy
  ngOnInit(): void {
    // aina kun sovellus käynnistyy, haetaan tiedot localstoragesta
    // tai luodaan sinne taulukko jos sitä ei ole aiemmin tehty.
    this.getCalcs();
    
  }

  // localstoragea servicen välityksellä käsittelevät metodit

  getCalcs(){
    this.calcs = this.sservice.getCalculations();
  }

  addCalcs(calc:string){
    this.sservice.addCalculation(calc);
  }

  reset(){
    this.sservice.resetStorage();
    this.getCalcs();
  }

  // Sovelluslogiikan tuottavat metodit
  
  public doPlus() {

    this.result = this.val1 + this.val2;
    const calc = this.val1 + ' + ' + this.val2 + ' = ' + this.result;
    this.addCalcs(calc);
    this.getCalcs();
  }

  public doMinus() {

    this.result = this.val1 - this.val2;
    const calc = this.val1 + ' - ' + this.val2 + ' = ' + this.result;
    this.addCalcs(calc);
    this.getCalcs();
  }

  public doMulti() {

    this.result = this.val1 * this.val2;
    const calc = this.val1 + ' * ' + this.val2 + ' = ' + this.result;
    this.addCalcs(calc);
    this.getCalcs();
  }
}
